@@ -39,7 +39,7 @@ class below(if need)
 ---------------------------
 """
 def printHelp():
-    print("--help below"+"-"*20))
+    print("--help below"+"-"*20)
     print("predictPicture modelpath picturepath")
 
 def callPredictPicture():
